summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorfig02 <fig02srl@gmail.com>2025-03-27 01:47:44 -0400
committerGitHub <noreply@github.com>2025-03-27 01:47:44 -0400
commit7416f413db78e8638bcb51bb9b4415c97a4d16c6 (patch)
tree45f1850b2e98120c7a0632c5924402907ac87146 /include
parent919b78ecbe516384ee2b65b0ed2b4e3582c209cc (diff)
SoundMode -> SoundOutputMode (#2475)
* SoundOutputMode, and move SoundSetting * missed a couple * format * move SoundSetting
Diffstat (limited to 'include')
-rw-r--r--include/audiothread_cmd.h10
-rw-r--r--include/seqcmd.h10
-rw-r--r--include/variables.h2
-rw-r--r--include/z64audio.h16
4 files changed, 19 insertions, 19 deletions
diff --git a/include/variables.h b/include/variables.h
index 845826b66..b6f1384fc 100644
--- a/include/variables.h
+++ b/include/variables.h
@@ -118,7 +118,7 @@ extern u8 gStartSeqDisabled;
#if DEBUG_FEATURES
extern u8 gAudioDebugPrintSeqCmd;
#endif
-extern u8 gSoundModeList[];
+extern u8 gSoundOutputModes[];
extern u8 gAudioSpecId;
extern u8 D_80133418;
extern AudioSpec gAudioSpecs[18];
diff --git a/include/z64audio.h b/include/z64audio.h
index 3673811ac..fdbbd6250 100644
--- a/include/z64audio.h
+++ b/include/z64audio.h
@@ -75,12 +75,12 @@ typedef enum SoundSetting {
/* 3 */ SOUND_SETTING_SURROUND
} SoundSetting;
-typedef enum SoundMode {
- /* 0 */ SOUNDMODE_STEREO,
- /* 1 */ SOUNDMODE_HEADSET,
- /* 2 */ SOUNDMODE_SURROUND,
- /* 3 */ SOUNDMODE_MONO
-} SoundMode;
+typedef enum SoundOutputMode {
+ /* 0 */ SOUND_OUTPUT_STEREO,
+ /* 1 */ SOUND_OUTPUT_HEADSET,
+ /* 2 */ SOUND_OUTPUT_SURROUND,
+ /* 3 */ SOUND_OUTPUT_MONO
+} SoundOutputMode;
typedef enum AdsrStatus {
/* 0 */ ADSR_STATE_DISABLED,
@@ -936,7 +936,7 @@ typedef struct AudioContext {
/* 0x2890 */ s32 maxAudioCmds;
/* 0x2894 */ s32 numNotes;
/* 0x2898 */ s16 maxTempo; // Maximum possible tempo (seqTicks per minute), using every tick as a seqTick to process a .seq file
- /* 0x289A */ s8 soundMode;
+ /* 0x289A */ s8 soundOutputMode;
/* 0x289C */ s32 totalTaskCount; // The total number of times the top-level function on the audio thread has run since audio was initialized
/* 0x28A0 */ s32 curAudioFrameDmaCount;
/* 0x28A4 */ s32 rspTaskIndex;
@@ -1204,7 +1204,7 @@ void func_800F64E0(u8 arg0);
void Audio_ToggleMalonSinging(u8 malonSingingDisabled);
void Audio_SetEnvReverb(s8 reverb);
void Audio_SetCodeReverb(s8 reverb);
-void Audio_SetSoundMode(s8 soundSetting);
+void Audio_SetSoundOutputMode(s8 soundSetting);
void Audio_SetBaseFilter(u8);
void Audio_SetExtraFilter(u8);
void Audio_SetCutsceneFlag(s8 flag);
diff --git a/include/audiothread_cmd.h b/include/audiothread_cmd.h
index c0576b82b..c4a343631 100644
--- a/include/audiothread_cmd.h
+++ b/include/audiothread_cmd.h
@@ -44,7 +44,7 @@ typedef enum AudioThreadCmdOp {
/* 0xE1 */ AUDIOCMD_OP_GLOBAL_SET_SFX_FONT,
/* 0xE2 */ AUDIOCMD_OP_GLOBAL_SET_INSTRUMENT_FONT,
/* 0xE3 */ AUDIOCMD_OP_GLOBAL_POP_PERSISTENT_CACHE,
- /* 0xF0 */ AUDIOCMD_OP_GLOBAL_SET_SOUND_MODE = 0xF0,
+ /* 0xF0 */ AUDIOCMD_OP_GLOBAL_SET_SOUND_OUTPUT_MODE = 0xF0,
/* 0xF1 */ AUDIOCMD_OP_GLOBAL_MUTE,
/* 0xF2 */ AUDIOCMD_OP_GLOBAL_UNMUTE,
/* 0xF3 */ AUDIOCMD_OP_GLOBAL_SYNC_LOAD_INSTRUMENT,
@@ -412,12 +412,12 @@ typedef enum AudioThreadCmdOp {
AudioThread_QueueCmdS32(AUDIO_MK_CMD(AUDIOCMD_OP_GLOBAL_POP_PERSISTENT_CACHE, 0, 0, 0), tableType)
/**
* Change the sound mode of audio
*
* @param soundMode (s32) see the `SoundMode` enum
*/
-#define AUDIOCMD_GLOBAL_SET_SOUND_MODE(soundMode) \
- AudioThread_QueueCmdS32(AUDIO_MK_CMD(AUDIOCMD_OP_GLOBAL_SET_SOUND_MODE, 0, 0, 0), soundMode)
+#define AUDIOCMD_GLOBAL_SET_SOUND_OUTPUT_MODE(soundOutputMode) \
+ AudioThread_QueueCmdS32(AUDIO_MK_CMD(AUDIOCMD_OP_GLOBAL_SET_SOUND_OUTPUT_MODE, 0, 0, 0), soundOutputMode)
/**
* Mute all sequence players
@@ -412,12 +412,12 @@ typedef enum AudioThreadCmdOp {
AudioThread_QueueCmdS32(AUDIO_MK_CMD(AUDIOCMD_OP_GLOBAL_POP_PERSISTENT_CACHE, 0, 0, 0), tableType)
/**
- * Change the sound mode of audio
+ * Change the sound output mode
*
@@ -412,12 +412,12 @@ typedef enum AudioThreadCmdOp {
*
- * @param soundMode (s32) see the `SoundMode` enum
+ * @param soundOutputMode (s32) see the `SoundOutputMode` enum
*/
diff --git a/include/seqcmd.h b/include/seqcmd.h
index 5acce7c49..53fce27bf 100644
--- a/include/seqcmd.h
+++ b/include/seqcmd.h
@@ -56,7 +56,7 @@ typedef enum SeqCmdSetupCmdOp {
// Subset of `SEQCMD_OP_GLOBAL_CMD`
typedef enum SeqCmdSubCmdOp {
- /* 0x0 */ SEQCMD_SUB_OP_GLOBAL_SET_SOUND_MODE,
+ /* 0x0 */ SEQCMD_SUB_OP_GLOBAL_SET_SOUND_OUTPUT_MODE,
/* 0x1 */ SEQCMD_SUB_OP_GLOBAL_DISABLE_NEW_SEQUENCES
} SeqCmdSubCmdOp;
@@ -479,12 +479,12 @@ typedef enum SeqCmdSubCmdOp {
*/
/**
* Change the sound mode of audio
*
* @param soundMode see the `SoundMode` enum
*/
-#define SEQCMD_SET_SOUND_MODE(soundMode) \
- Audio_QueueSeqCmd((SEQCMD_OP_GLOBAL_CMD << 28) | (SEQCMD_SUB_OP_GLOBAL_SET_SOUND_MODE << 8) | (u8)(soundMode))
+#define SEQCMD_SET_SOUND_OUTPUT_MODE(soundOutputMode) \
+ Audio_QueueSeqCmd((SEQCMD_OP_GLOBAL_CMD << 28) | (SEQCMD_SUB_OP_GLOBAL_SET_SOUND_OUTPUT_MODE << 8) | (u8)(soundOutputMode))
/**
* Disable (or reenable) new sequences from starting
@@ -479,12 +479,12 @@ typedef enum SeqCmdSubCmdOp {
*/
/**
- * Change the sound mode of audio
+ * Change the sound output mode
*
@@ -479,12 +479,12 @@ typedef enum SeqCmdSubCmdOp {
*
- * @param soundMode see the `SoundMode` enum
+ * @param soundOutputMode see the `SoundOutputMode` enum
*/